DeserializeBytes

Struct DeserializeBytes 

pub struct DeserializeBytes { /* private fields */ }
An abstract representation of bytes remaining after a deserialization failure.

Implementations

Source

impl DeserializeBytes

pub fn new() -> Self

Creates an empty SerializeBytes. This is the only method clients should use– the only other way to get an instance is to get one returned from deserialize.